# generated by datamodel-codegen:
#   filename:  get_data.json

from __future__ import annotations

from pydantic import BaseModel


class GetData(BaseModel):
    """
    Get Data
    """

    modules: list
