# generated by datamodel-codegen:
#   filename:  update_setting.json

from __future__ import annotations

from typing import Any

from pydantic import BaseModel


class UpdateSetting(BaseModel):
    """
    Update Setting
    """

    setting: str
    value: Any
