"""
Provides systembridgeconnector version information.
"""

# This file is auto-generated! Do not edit!
# Use `python -m incremental.update systembridgeconnector` to change this file.

from incremental import Version

__version__ = Version("systembridgeconnector", 3, 4, 4)
__all__ = ["__version__"]
