# generated by datamodel-codegen:
#   filename:  update.json

from __future__ import annotations

from pydantic import BaseModel


class Update(BaseModel):
    """
    Version
    """

    version: str
