# generated by datamodel-codegen:
#   filename:  keyboard_text.json

from __future__ import annotations

from pydantic import BaseModel


class KeyboardText(BaseModel):
    """
    Keyboard Text
    """

    text: str
