# generated by datamodel-codegen:
#   filename:  media_get_file.json

from __future__ import annotations

from pydantic import BaseModel


class MediaGetFile(BaseModel):
    """
    Get File
    """

    base: str
    path: str
