# generated by datamodel-codegen:
#   filename:  register_data_listener.json

from __future__ import annotations

from pydantic import BaseModel


class RegisterDataListener(BaseModel):
    """
    Register Data Listener
    """

    modules: list
